@@ -6,14 +6,12 @@ use Data::Visitor::Callback;
 
 requires 'expand';
 
-has visitor => (
-    is => 'ro',
-    isa => 'Data::Visitor::Callback',
-    lazy_build => 1,
-);
+our $VISITOR;
 
-sub _build_visitor {
-    return Data::Visitor::Callback->new(
+sub expand_all_injections {
+    my ($self, $c, $thing) = @_;
+
+    $VISITOR ||= Data::Visitor::Callback->new(
         object_final => sub {
             my ($visitor, $object) = @_;
             my $DOES = $object->can('DOES');
@@ -23,14 +21,8 @@ sub _build_visitor {
             return $object;
         }
     );
-}
-
-sub expand_all_injections {
-    my ($self, $c, $thing) = @_;
-
-    my $visitor = $self->visitor;
-    local $visitor->{OROCHI} = $c;
-    $visitor->visit($thing);
+    local $VISITOR->{OROCHI} = $c;
+    $VISITOR->visit($thing);
 }
 
 1;
\ No newline at end of file
